@@ -260,7 +260,12 @@ class DocParser:
             if not os.path.exists(save_path):
                 os.makedirs(save_path)
 
-            filename =  os.path.join(save_path, attachment["filename"])
+            #generate random filename for attachment if for some reason it is missing
+            if(attachment["filename"] == ""):
+                filename = os.path.join(save_path, uuid.uuid4().hex + attachment[META_FIELD]["extension"])
+            else:
+                filename =  os.path.join(save_path, attachment["filename"])
+            
             shutil.copyfile(attachment[META_FIELD]["path"], filename)
             attachment[META_FIELD]["location"] = filename
         return True
@@ -279,7 +284,7 @@ class DocParser:
         return True
 
     def _parse_attachment(self, attachment):
-        parsed_attachment = list(self._parse(attachment["content"], attachment["filename"])) #this could be a list of multiple files
+        parsed_attachment = list(self._parse(attachment["content"], attachment["filename"], save_to_file=False)) #this could be a list of multiple files
 
         extracted_attachments = []
         for ix, sub_file in enumerate(parsed_attachment):
@@ -303,9 +308,11 @@ class DocParser:
             
         return extracted_attachments
 
-    def _parse(self, parser_input, file_name=None):
+    def _parse(self, parser_input, file_name=None, save_to_file=True):
         """
         :param: str parser_input: Base64 string or file path.
+        :param: bool save_to_file: As this function is recursive, specifies whether the file
+            should be saved so it won't be saved multiple times when parsing complex structures.
         """
         if isinstance(parser_input, bytes):
             # input is in bytes
@@ -348,8 +355,8 @@ class DocParser:
 
                 #email parser handles all the errors and logs uncaught
                 elif (meta["extension"] in Extension.EMAIL_EXTENSIONS):
-                    parser = EmailParser(tmp_folder=self.temp_dir)
-                    generator = parser.parse(meta["path"])
+                    parser = EmailParser(tmp_folder=self.temp_dir, save_path=self.save_path)
+                    generator = parser.parse(meta["path"], save_mails=self.save_mails)
 
                     for msg_dict, attachment_dicts in generator:
                         msg_dict[META_FIELD] = meta.copy() # add metadata to email dictionary
@@ -367,12 +374,14 @@ class DocParser:
 
                         # save attachments if specified
                         for attachment in extracted_attachments:
-                            self.save_attachment(attachment)
+                            if("subject" not in attachment): #is actually mail, do not save it (already in email_parser if specified so!)
+                                self.save_attachment(attachment)
                         
                         yield msg_dict, extracted_attachments
 
                 elif (meta["extension"] in Extension.COLLECTION_EXTENSIONS):
-                    self.save_document(meta)
+                    if(save_to_file):
+                        self.save_document(meta)
                     generator = self._parse_collection(meta)
                     try:
                         for item in generator:
@@ -385,7 +394,8 @@ class DocParser:
                         yield {META_FIELD: meta}
                     
                 else:
-                    self.save_document(meta)
+                    if(save_to_file):
+                        self.save_document(meta)
                     try:
                         for parsed_document in self._parse_file(meta, languages=self.langs):
                             parsed_document[META_FIELD] = meta.copy()
