@@ -13,13 +13,14 @@ logging.basicConfig(
 
 class MLPProcessor:
 
-    def __init__(self, mlp, use_celery=False, app=None):
+    def __init__(self, mlp, use_celery=False, app=None, worker_name="worker.taskman.mlp"):
         self.mlp = mlp
         self.processing_functions = {
             "Normal": self._apply_mlp,
             "Celery": self._apply_mlp_celery
         }
         self.celery = use_celery
+        self.worker_name = worker_name
         if use_celery and app:
             self.app = app
 
@@ -47,7 +48,7 @@ class MLPProcessor:
 
     def _apply_mlp_celery(self, document: dict, field: str, analyzers: list):
         try:
-            result = self.app.send_task("worker.taskman.mlp", args=[[document], [field], analyzers])
+            result = self.app.send_task(self.worker_name, args=[[document], [field], analyzers])
 
             while not result.ready():
                 time.sleep(0.1)
